#!/usr/bin/env bash
set -o errexit -o nounset -o pipefail
#set -o xtrace

start() {
  local vm=unattended-templates-dir-bug
  local ostype=Debian_64
  local os_iso_url=https://cdimage.debian.org/cdimage/release/9.7.0/amd64/iso-cd/debian-9.7.0-amd64-netinst.iso

  local os_iso=~/tmp/isos/$(basename $os_iso_url)
  local base_dir=~/tmp/$USER-vms

  mkdir -p $(dirname $os_iso)

  if ! test -e $os_iso; then
    curl --fail --location --create-dirs --output $os_iso-$$ $os_iso_url
    mv $os_iso-$$ $os_iso # this only happens if previous cmds succeeds (because of errexit)
  fi

  # remove any failed previous attempt
  VBoxManage controlvm    $vm poweroff > /dev/null 2>&1 || true
  VBoxManage unregistervm $vm --delete > /dev/null 2>&1 || true
  
  rm -fr   $base_dir/$vm
  mkdir -p $base_dir/$vm

  VBoxManage createvm \
    --name       $vm       \
    --basefolder $base_dir \
    --ostype     $ostype   \
    --register             \

  VBoxManage modifyvm $vm \
    --memory 1024 \
    --vram   16   \

  VBoxManage storagectl $vm \
    --name        SAS \
    --add         sas \
    --portcount   1   \
    --bootable    on  \

  VBoxManage createmedium disk \
    --filename $base_dir/$vm/$vm.vdi \
    --size     8192                  \
    --format   VDI                   \

  # SAS-0-0
  VBoxManage storageattach $vm \
    --medium     $base_dir/$vm/$vm.vdi \
    --storagectl SAS                   \
    --port       0                     \
    --device     0                     \
    --type       hdd                   \

  VBoxManage storagectl $vm \
    --name        SATA \
    --add         sata \
    --portcount   1    \
    --bootable    on   \

  # SATA-0-0
  VBoxManage storageattach $vm \
    --medium     emptydrive \
    --storagectl SATA       \
    --port       0          \
    --device     0          \
    --type       dvddrive   \
    --mtype      readonly   \

  if test ${fix:-0} -ne 0; then
    local script_template=/usr/lib/virtualbox/UnattendedTemplates/debian_preseed.cfg
    local post_install_template=/usr/lib/virtualbox/UnattendedTemplates/debian_postinstall.sh

    VBoxManage unattended install $vm \
      --iso                   $os_iso          \
      --script-template       $script_template \
      --post-install-template $post_install_template
  else
    VBoxManage unattended install $vm \
      --iso $os_iso
  fi

  VBoxManage startvm $vm --type headless
}
start
